diff libpurple/protocols/yahoo/yahoo_filexfer.h @ 15822:32c366eeeb99

sed -ie 's/gaim/purple/g'
author Sean Egan <seanegan@gmail.com>
date Mon, 19 Mar 2007 07:01:17 +0000
parents 5fe8042783c1
children 44b4e8bd759b
line wrap: on
line diff
--- a/libpurple/protocols/yahoo/yahoo_filexfer.h	Mon Mar 19 06:11:46 2007 +0000
+++ b/libpurple/protocols/yahoo/yahoo_filexfer.h	Mon Mar 19 07:01:17 2007 +0000
@@ -1,7 +1,7 @@
 /*
- * gaim
+ * purple
  *
  * Gaim is the legal property of its developers, whose names are too numerous
  * to list here.  Please refer to the COPYRIGHT file distributed with this
  * source distribution.
  *
@@ -27,28 +27,28 @@
 /**
  * Process ymsg events, particular IMViroments like Doodle
  */
-void yahoo_process_p2pfilexfer( GaimConnection *gc, struct yahoo_packet *pkt );
+void yahoo_process_p2pfilexfer( PurpleConnection *gc, struct yahoo_packet *pkt );
 
 /**
  * Process ymsg file receive invites.
  */
-void yahoo_process_filetransfer(GaimConnection *gc, struct yahoo_packet *pkt);
+void yahoo_process_filetransfer(PurpleConnection *gc, struct yahoo_packet *pkt);
 
 /**
  * Create a new GaimXfer
  *
  * @param gc The GaimConnection handle.
  * @param who Who will we be sending it to?
  */
-GaimXfer *yahoo_new_xfer(GaimConnection *gc, const char *who);
+PurpleXfer *yahoo_new_xfer(PurpleConnection *gc, const char *who);
 
 /**
  * Send a file.
  *
  * @param gc The GaimConnection handle.
  * @param who Who are we sending it to?
  * @param file What file? If NULL, user will choose after this call.
  */
-void yahoo_send_file(GaimConnection *gc, const char *who, const char *file);
+void yahoo_send_file(PurpleConnection *gc, const char *who, const char *file);
 
 #endif
@@ -1,7 +1,7 @@
  *
- * Gaim is the legal property of its developers, whose names are too numerous
+ * Purple is the legal property of its developers, whose names are too numerous
  * to list here.  Please refer to the COPYRIGHT file distributed with this
  * source distribution.
@@ -27,28 +27,28 @@
 
 /**
- * Create a new GaimXfer
+ * Create a new PurpleXfer
  *
@@ -27,28 +27,28 @@
  *
- * @param gc The GaimConnection handle.
+ * @param gc The PurpleConnection handle.
  * @param who Who will we be sending it to?
  */
@@ -27,28 +27,28 @@
  * Send a file.
  *
- * @param gc The GaimConnection handle.
+ * @param gc The PurpleConnection handle.
  * @param who Who are we sending it to?
  * @param file What file? If NULL, user will choose after this call.